@@ -133,8 +133,6 @@ class Client(object):
 
         o = options
 
-        self.configure_logging()
-
         self.raise_send_errors = raise_send_errors
 
         # configure loggers first
@@ -225,14 +223,6 @@ class Client(object):
     def register_scheme(cls, scheme, transport_class):
         cls._registry.register_scheme(scheme, transport_class)
 
-    def configure_logging(self):
-        for name in ('raven', 'sentry'):
-            logger = logging.getLogger(name)
-            if logger.handlers:
-                continue
-            logger.addHandler(logging.StreamHandler())
-            logger.setLevel(logging.INFO)
-
     def get_processors(self):
         for processor in self.processors:
             yield self.module_cache[processor](self)
@@ -284,8 +274,11 @@ class Client(object):
 
     def _get_exception_key(self, exc_info):
         return (
+            exc_info[0],
             id(exc_info[1]),
+            id(exc_info[2].tb_frame.f_code),
             id(exc_info[2]),
+            exc_info[2].tb_lasti,
         )
 
     def skip_error_for_logging(self, exc_info):
@@ -653,8 +646,7 @@ class Client(object):
     def send_encoded(self, message, auth_header=None, **kwargs):
         """
         Given an already serialized message, signs the message and passes the
-        payload off to ``send_remote`` for each server specified in the servers
-        configuration.
+        payload off to ``send_remote``.
         """
         client_string = 'raven-python/%s' % (raven.VERSION,)
 
@@ -721,7 +713,7 @@ class Client(object):
 
         ``kwargs`` are passed through to ``.capture``.
         """
-        if exc_info is None:
+        if exc_info is None or exc_info is True:
             exc_info = sys.exc_info()
         return self.capture(
             'raven.events.Exception', exc_info=exc_info, **kwargs)
